@@ -1,20 +1,18 @@
 /*-------------------------------------------------------------------------
  *
  * logtofile.h
- *      pgaudit addon to redirect audit log lines to an independent file
+ *      Main entry point for logtofile
  *
- * Copyright (c) 2020-2023, Francisco Miguel Biete Banon
- * Copyright (c) 2014, 2ndQuadrant Ltd.
+ * Copyright (c) 2020-2024, Francisco Miguel Biete Banon
  *
  * This code is released under the PostgreSQL licence, as given at
  *  http://www.postgresql.org/about/licence/
  *-------------------------------------------------------------------------
  */
-#ifndef PGAUDITLOGTOFILE_H
-#define PGAUDITLOGTOFILE_H
+#ifndef _LOGTOFILE_H_
+#define _LOGTOFILE_H_
 
-/* initialization functions */
-void _PG_fini(void);
 void _PG_init(void);
+void _PG_fini(void);
 
 #endif
